<?php

declare(strict_types=1);

namespace Drupal\content_commander;

use Drupal\Core\Entity\ContentEntityInterface;

final class ContentContext {

  /**
   * @phpstan-param \SplObjectStorage<\Drupal\content_commander\ContentInterface, \Drupal\Core\Entity\ContentEntityInterface> $dependencies
   * @phpstan-param \SplObjectStorage<\Drupal\content_commander\ContentInterface, mixed> $requiredDependencies
   */
  private function __construct(
    private readonly ContentInterface $for,
    private readonly \SplObjectStorage $dependencies,
    private \SplObjectStorage $requiredDependencies,
  ) {
  }

  /**
   * Must be invoked with named parameters.
   *
   * @phpstan-param \SplObjectStorage<\Drupal\content_commander\ContentInterface, \Drupal\Core\Entity\ContentEntityInterface> $dependencies
   * @phpstan-param \SplObjectStorage<\Drupal\content_commander\ContentInterface, mixed> $requiredDependencies
   *
   * @internal
   */
  public static function create(
    ContentInterface $for,
    \SplObjectStorage $dependencies,
    \SplObjectStorage $requiredDependencies,
  ): static {
    return new static($for, $dependencies, $requiredDependencies);
  }

  /**
   * Gets the content required.
   */
  public function getDependency(ContentInterface $content): ContentEntityInterface {
    $entity = $this->dependencies[$content] ?? throw new \Exception(\sprintf(
      '%s is not listed as a dependency of %s so the entity is not available.',
      ($content::class . '::' . $content->name),
      ($this->for::class . '::' . $this->for->name),
    ));

    unset($this->requiredDependencies[$content]);

    return $entity;
  }

  /**
   * @phpstan-return iterable<\Drupal\content_commander\ContentInterface>
   */
  public function unusedDependencies(): iterable {
    return $this->requiredDependencies;
  }

}
