<?php

declare(strict_types=1);

namespace Drupal\content_commander;

use Drupal\Core\Entity\ContentEntityInterface;

interface ContentInterface extends \UnitEnum {

  /**
   * Build an entity for the enum in context.
   *
   * The entity is already created with the UUID prefilled.
   */
  public function createContent(ContentContext $contentContext, ContentEntityInterface $entity): void;

  /**
   * Build a UUID for the enum in context.
   *
   * If enum values are UUIDs, just return `$this->value`.
   *
   * The returned string must be different for each enum. UUIDs only have to be
   * unique within an entity type; UUID's do not collide with different entity
   * types.
   *
   * Return NULL if you want to let CC manage the UUID map. Note that UUIDs will
   * then be randomly generated.
   */
  public function uuid(): ?string;

  /**
   * Determine the entity type.
   *
   * An entity type class or bundle class.
   *
   * @phpstan-return class-string<\Drupal\Core\Entity\ContentEntityInterface>
   */
  public function entityClass(): string;

  /**
   * Gets an entity for an enum.
   *
   * The entity must be created beforehand with the relevant console command.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface|null
   *   Returns NULL if the entity has not been created.
   */
  public function entity(): ?ContentEntityInterface;

}
