<?php

declare(strict_types=1);

namespace Drupal\content_commander;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeRepositoryInterface;

final class ContentRepository implements ContentRepositoryInterface {

  public function __construct(
    private readonly EntityTypeRepositoryInterface $entityTypeRepository,
    private readonly EntityRepositoryInterface $entityRepository,
    private readonly ConfigFactoryInterface $configFactory,
  ) {
  }

  public function getEntity(ContentInterface $enum): ?ContentEntityInterface {
    $uuid = $enum->uuid();
    if ($uuid === NULL) {
      // The mapping will be in config.
      /** @var array<string, string> $map */
      $map = $this->configFactory
        ->get('content_commander.content_mapping')
        ->get('map') ?? [];

      $enumKey = $enum::class . '::' . $enum->name;
      $uuid = $map[$enumKey] ?? NULL;
      if ($uuid === NULL) {
        return NULL;
      }
    }

    $entityClass = $enum->entityClass();
    $entityTypeId = $this->entityTypeRepository->getEntityTypeFromClass($entityClass);
    /** @var \Drupal\Core\Entity\ContentEntityInterface|null */
    return $this->entityRepository->loadEntityByUuid($entityTypeId, $uuid);
  }

}
