<?php

declare(strict_types=1);

namespace Drupal\content_commander_test\ContentCommander;

use Drupal\content_commander\Attribute\DependsOn;
use Drupal\content_commander\ContentContext;
use Drupal\content_commander\ContentInterface;
use Drupal\content_commander\ContentTrait;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\entity_test\Entity\EntityTest;
use Symfony\Component\Console\Attribute\AsCommand;

/**
 * A verbose but simplified example of a content enum.
 */
#[AsCommand('content-commander-test:test')]
enum CcTestContent implements ContentInterface {

  use ContentTrait;

  case Content1;

  #[DependsOn(self::Content1)]
  case Content2;

  #[DependsOn(self::Content2)]
  case Content3;

  #[DependsOn(self::Content2)]
  case Content4;

  #[DependsOn(self::Content2), DependsOn(self::Content4)]
  case Content5;

  public function createContent(ContentContext $contentContext, ContentEntityInterface $entity): void {
    \assert($entity instanceof EntityTest);

    // Typically I'd use a self executing match-macro, but use "if"s here for
    // readability.
    if ($this === self::Content1) {
      $entity->setName('Content 1');
    }
    elseif ($this === self::Content2) {
      $other = $contentContext->getDependency(self::Content1);
      // Entity label will be "Content 2 (Content 1)".
      $entity->setName(\sprintf('Content 2 (%s)', $other->label()));
    }
    elseif ($this === self::Content3) {
      $other = $contentContext->getDependency(self::Content2);
      // Entity label will be "Content 3 (Content 2 (Content 1))".
      $entity->setName(\sprintf('Content 3 (%s)', $other->label()));
    }
    elseif ($this === self::Content4) {
      $other = $contentContext->getDependency(self::Content2);
      // Entity label will be "Content 4 (Content 2 (Content 1))".
      $entity->setName(\sprintf('Content 4 (%s)', $other->label()));
    }
    elseif ($this === self::Content5) {
      $other1 = $contentContext->getDependency(self::Content2);
      $other2 = $contentContext->getDependency(self::Content4);
      // Entity label will be "Content 5 (Content 1 + Content 2 (Content 1))".
      $entity->setName(\sprintf('Content 5 (%s + %s)', $other1->label(), $other2->label()));
    }
  }

  public function entityClass(): string {
    return EntityTest::class;
  }

}
