<?php

declare(strict_types=1);

namespace Drupal\content_commander_test\ContentCommander;

use Drupal\content_commander\Attribute\DependsOn;
use Drupal\content_commander\ContentContext;
use Drupal\content_commander\ContentInterface;
use Drupal\content_commander\ContentTrait;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\entity_test\Entity\EntityTest;
use Symfony\Component\Console\Attribute\AsCommand;

/**
 * Test content where the enum is not backed by a value.
 */
#[AsCommand('content-commander-test:non-backed')]
enum CcTestContentNonBacked implements ContentInterface {

  use ContentTrait;

  case Content1;

  #[DependsOn(self::Content1)]
  case Content2;

  public function createContent(ContentContext $contentContext, ContentEntityInterface $entity): void {
    \assert($entity instanceof EntityTest);
    (match ($this) {
      self::Content1 => static function (EntityTest $entity): void {
        $entity->setName('Foo 1');
      },
      self::Content2 => static function (EntityTest $entity) use ($contentContext): void {
        $dep1 = $contentContext->getDependency(self::Content1);
        $entity->setName(\sprintf('Foo 2 (%s)', \implode(', ', [$dep1->label()])));
      },
    })($entity);
  }

  public function entityClass(): string {
    return EntityTest::class;
  }

}
