<?php

declare(strict_types=1);

namespace Drupal\content_commander_test\ContentCommander;

use Drupal\content_commander\Attribute\DependsOn;
use Drupal\content_commander\ContentContext;
use Drupal\content_commander\ContentInterface;
use Drupal\content_commander\ContentTrait;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\entity_test\Entity\EntityTest;
use Symfony\Component\Console\Attribute\AsCommand;

/**
 * Test content where enum values are UUIDS, as returned by a method.
 */
#[AsCommand('content-commander-test:uuid-values')]
enum CcTestUuidAsBackedValues: string implements ContentInterface {

  use ContentTrait;

  case Content1 = 'abcaaaaa-bbbb-aaaa-aaaa-000000000001';

  #[DependsOn(self::Content1)]
  case Content2 = 'abcaaaaa-bbbb-aaaa-aaaa-000000000002';

  public function createContent(ContentContext $contentContext, ContentEntityInterface $entity): void {
    \assert($entity instanceof EntityTest);
    (match ($this) {
      self::Content1 => static function (EntityTest $entity): void {
        $entity->setName('Foo 1');
      },
      self::Content2 => static function (EntityTest $entity) use ($contentContext): void {
        $dep1 = $contentContext->getDependency(self::Content1);
        $entity->setName(\sprintf('Foo 2 (%s)', \implode(', ', [$dep1->label()])));
      },
    })($entity);
  }

  public function uuid(): ?string {
    return $this->value;
  }

  public function entityClass(): string {
    return EntityTest::class;
  }

}
